coherence.upnp.core.action (module) — Cohen3 0.8.0 documentation

# coherence.upnp.core.action (module)

class `Argument`(name, direction, state_variable)

  Bases: `object`

  `get_name`()
  `get_direction`()
  `get_state_variable`()
  `as_tuples`()
  `as_dict`()

class `Action`(service, name, implementation, arguments_list)

  Bases: `coherence.log.LogAble`

  `logCategory` = 'action'
  `_get_client`()
  `get_name`()
  `get_implementation`()
  `get_arguments_list`()
  `get_in_arguments`()
  `get_out_arguments`()
  `get_service`()
  `set_callback`(callback)
  `get_callback`()
  `call`(*args, **kwargs)
  `got_results`(results, instance_id, name)
  `as_tuples`()
  `as_dict`()